{
  am_pm_abbreviated => [
    "\N{U+090f}\N{U+202f}\N{U+090f}\N{U+092e}",
    "\N{U+092a}\N{U+0940}\N{U+202f}\N{U+090f}\N{U+092e}",
  ],
  available_formats => {
    Bh => "B h",
    Bhm => "B h:mm",
    Bhms => "B h:mm:ss",
    E => "ccc",
    EBhm => "E B h:mm",
    EBhms => "E B h:mm:ss",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM G y",
    GyMMMEd => "E, d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    "MMMMW-count-other" => "MMMM \N{U+0924}\N{U+093e}\N{U+0901} \N{U+0935}\N{U+093e}\N{U+0930}\N{U+093e} W",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "Y \N{U+0924}\N{U+093e}\N{U+0901} \N{U+0935}\N{U+093e}\N{U+0930}\N{U+093e} w",
  },
  code => "kxv-Deva",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1} \N{U+0906}\N{U+0901} {0}",
  datetime_format_long => "{1} \N{U+0906}\N{U+0901} {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "\N{U+0938}\N{U+093e}\N{U+0945}\N{U+092e}\N{U+094d}\N{U+092e}\N{U+093e}",
    "\N{U+092e}\N{U+093e}\N{U+0928}\N{U+094d}\N{U+0917}\N{U+093e}",
    "\N{U+092a}\N{U+0942}\N{U+0926}\N{U+093e}",
    "\N{U+0932}\N{U+093e}\N{U+0915}\N{U+094d}\N{U+0915}\N{U+0940}",
    "\N{U+0938}\N{U+0941}\N{U+0915}\N{U+0941}\N{U+0930}\N{U+0941}",
    "\N{U+0938}\N{U+093e}\N{U+0928}\N{U+094d}\N{U+0928}\N{U+093f}",
    "\N{U+0906}\N{U+0926}\N{U+093f}",
  ],
  day_format_narrow => [
    "\N{U+0938}\N{U+093e}\N{U+0945}",
    "\N{U+092e}\N{U+093e}",
    "\N{U+092a}\N{U+0942}",
    "\N{U+0932}\N{U+093e}",
    "\N{U+0938}\N{U+0941}",
    "\N{U+0938}\N{U+093e}",
    "\N{U+0906}",
  ],
  day_format_wide => [
    "\N{U+0938}\N{U+093e}\N{U+0945}\N{U+092e}\N{U+094d}\N{U+0935}\N{U+093e}\N{U+0930}\N{U+093e}",
    "\N{U+092e}\N{U+0902}\N{U+0917}\N{U+093e}\N{U+0921}\N{U+093c}\N{U+093e}",
    "\N{U+092a}\N{U+0941}\N{U+0926}\N{U+094d}\N{U+0926}\N{U+093e}\N{U+0930}\N{U+093e}",
    "\N{U+0932}\N{U+093e}\N{U+0915}\N{U+094d}\N{U+0915}\N{U+093f} \N{U+0935}\N{U+093e}\N{U+0930}\N{U+093e}",
    "\N{U+0938}\N{U+0941}\N{U+0915}\N{U+0941}\N{U+0930}\N{U+0941} \N{U+0935}\N{U+093e}\N{U+0930}\N{U+093e}",
    "\N{U+0938}\N{U+093e}\N{U+0928}\N{U+094d}\N{U+0928}\N{U+093f} \N{U+0935}\N{U+093e}\N{U+0930}\N{U+093e}",
    "\N{U+0906}\N{U+0926}\N{U+093f} \N{U+0935}\N{U+093e}\N{U+0930}\N{U+093e}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+0938}\N{U+093e}\N{U+0945}\N{U+092e}\N{U+094d}\N{U+092e}\N{U+093e}",
    "\N{U+092e}\N{U+093e}\N{U+0928}\N{U+094d}\N{U+0917}\N{U+093e}",
    "\N{U+092a}\N{U+0942}\N{U+0926}\N{U+093e}",
    "\N{U+0932}\N{U+093e}\N{U+0915}\N{U+094d}\N{U+0915}\N{U+0940}",
    "\N{U+0938}\N{U+0941}\N{U+0915}\N{U+0941}\N{U+0930}\N{U+0941}",
    "\N{U+0938}\N{U+093e}\N{U+0928}\N{U+094d}\N{U+0928}\N{U+093f}",
    "\N{U+0906}\N{U+0926}\N{U+093f}",
  ],
  day_stand_alone_narrow => [
    "\N{U+0938}\N{U+093e}\N{U+0945}",
    "\N{U+092e}\N{U+093e}",
    "\N{U+092a}\N{U+0942}",
    "\N{U+0932}\N{U+093e}",
    "\N{U+0938}\N{U+0941}",
    "\N{U+0938}\N{U+093e}",
    "\N{U+0906}",
  ],
  day_stand_alone_wide => [
    "\N{U+0938}\N{U+093e}\N{U+0945}\N{U+092e}\N{U+094d}\N{U+0935}\N{U+093e}\N{U+0930}\N{U+093e}",
    "\N{U+092e}\N{U+0902}\N{U+0917}\N{U+093e}\N{U+0921}\N{U+093c}\N{U+093e}",
    "\N{U+092a}\N{U+0941}\N{U+0926}\N{U+094d}\N{U+0926}\N{U+093e}\N{U+0930}\N{U+093e}",
    "\N{U+0932}\N{U+093e}\N{U+0915}\N{U+094d}\N{U+0915}\N{U+093f} \N{U+0935}\N{U+093e}\N{U+0930}\N{U+093e}",
    "\N{U+0938}\N{U+0941}\N{U+0915}\N{U+0941}\N{U+0930}\N{U+0941} \N{U+0935}\N{U+093e}\N{U+0930}\N{U+093e}",
    "\N{U+0938}\N{U+093e}\N{U+0928}\N{U+094d}\N{U+0928}\N{U+093f} \N{U+0935}\N{U+093e}\N{U+0930}\N{U+093e}",
    "\N{U+0906}\N{U+0926}\N{U+093f} \N{U+0935}\N{U+093e}\N{U+0930}\N{U+093e}",
  ],
  era_abbreviated => [
    "\N{U+092c}\N{U+093f}\N{U+0938}\N{U+093f}",
    "\N{U+090f}-\N{U+0921}\N{U+093f}",
  ],
  era_narrow => [
    "\N{U+092c}\N{U+093f}\N{U+0938}\N{U+093f}",
    "\N{U+090f}-\N{U+0921}\N{U+093f}",
  ],
  era_wide => [
    "\N{U+092c}\N{U+093f}\N{U+092b}\N{U+094b}\N{U+0930} \N{U+0915}\N{U+094d}\N{U+0930}\N{U+093e}\N{U+0907}\N{U+0938}\N{U+094d}\N{U+091f}",
    "\N{U+0905}\N{U+0928}\N{U+094d}\N{U+0928}\N{U+094b} \N{U+0921}\N{U+094b}\N{U+092e}\N{U+093f}\N{U+0928}\N{U+0940}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Kuvi",
  month_format_abbreviated => [
    "\N{U+092a}\N{U+0941}\N{U+0938}\N{U+0941}",
    "\N{U+092e}\N{U+093e}\N{U+0939}\N{U+093e}",
    "\N{U+092a}\N{U+093e}\N{U+0917}\N{U+0941}",
    "\N{U+0939}\N{U+093f}\N{U+0930}\N{U+094d}\N{U+0930}\N{U+0947}",
    "\N{U+092c}\N{U+0947}\N{U+0938}\N{U+0947}",
    "\N{U+091c}\N{U+093e}\N{U+091f}\N{U+094d}\N{U+091f}\N{U+093e}",
    "\N{U+0906}\N{U+0938}\N{U+093e}\N{U+0921}\N{U+093c}\N{U+0940}",
    "\N{U+0938}\N{U+094d}\N{U+0930}\N{U+093e}\N{U+092c}\N{U+093e}\N{U+0901}",
    "\N{U+092c}\N{U+093e}\N{U+0945}\N{U+0926}\N{U+094b}",
    "\N{U+0926}\N{U+093e}\N{U+0938}\N{U+093e}\N{U+0930}\N{U+093e}",
    "\N{U+0926}\N{U+093f}\N{U+0935}\N{U+0940}",
    "\N{U+092a}\N{U+093e}\N{U+0928}\N{U+094d}\N{U+0921}\N{U+0947}",
  ],
  month_format_narrow => [
    "\N{U+092a}\N{U+0941}",
    "\N{U+092e}\N{U+093e}",
    "\N{U+092a}\N{U+093e}",
    "\N{U+0939}\N{U+093f}",
    "\N{U+092c}\N{U+0947}",
    "\N{U+091c}\N{U+093e}",
    "\N{U+0906}",
    "\N{U+0938}\N{U+094d}\N{U+0930}\N{U+093e}",
    "\N{U+092c}\N{U+093e}\N{U+0945}",
    "\N{U+0926}\N{U+093e}",
    "\N{U+0926}\N{U+093f}",
    "\N{U+092a}\N{U+093e}",
  ],
  month_format_wide => [
    "\N{U+092a}\N{U+0941}\N{U+0938}\N{U+0941} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
    "\N{U+092e}\N{U+093e}\N{U+0939}\N{U+093e}\N{U+0915}\N{U+093e} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
    "\N{U+092a}\N{U+093e}\N{U+0917}\N{U+0941}\N{U+0923}\N{U+0940} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
    "\N{U+0939}\N{U+093f}\N{U+0930}\N{U+0947} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
    "\N{U+092c}\N{U+0947}\N{U+0938}\N{U+0947} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
    "\N{U+091c}\N{U+093e}\N{U+091f}\N{U+093e} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
    "\N{U+0906}\N{U+0938}\N{U+093e}\N{U+0921}\N{U+093c}\N{U+0940} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
    "\N{U+0938}\N{U+094d}\N{U+0930}\N{U+093e}\N{U+092c}\N{U+093e}\N{U+0901} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
    "\N{U+092c}\N{U+094b}\N{U+0926}\N{U+094b} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
    "\N{U+0926}\N{U+0938}\N{U+093e}\N{U+0930}\N{U+093e} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
    "\N{U+0926}\N{U+093f}\N{U+0935}\N{U+0940} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
    "\N{U+092a}\N{U+093e}\N{U+0928}\N{U+094d}\N{U+0921}\N{U+0947} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+092a}\N{U+0941}\N{U+0938}\N{U+0941}",
    "\N{U+092e}\N{U+093e}\N{U+0939}\N{U+093e}",
    "\N{U+092a}\N{U+093e}\N{U+0917}\N{U+0941}",
    "\N{U+0939}\N{U+093f}\N{U+0930}\N{U+094d}\N{U+0930}\N{U+0947}",
    "\N{U+092c}\N{U+0947}\N{U+0938}\N{U+0947}",
    "\N{U+091c}\N{U+093e}\N{U+091f}\N{U+094d}\N{U+091f}\N{U+093e}",
    "\N{U+0906}\N{U+0938}\N{U+093e}\N{U+0921}\N{U+093c}\N{U+0940}",
    "\N{U+0938}\N{U+094d}\N{U+0930}\N{U+093e}\N{U+092c}\N{U+093e}\N{U+0901}",
    "\N{U+092c}\N{U+093e}\N{U+0945}\N{U+0926}\N{U+094b}",
    "\N{U+0926}\N{U+093e}\N{U+0938}\N{U+093e}\N{U+0930}\N{U+093e}",
    "\N{U+0926}\N{U+093f}\N{U+0935}\N{U+0940}",
    "\N{U+092a}\N{U+093e}\N{U+0928}\N{U+094d}\N{U+0921}\N{U+0947}",
  ],
  month_stand_alone_narrow => [
    "\N{U+092a}\N{U+0941}",
    "\N{U+092e}\N{U+093e}",
    "\N{U+092a}\N{U+093e}",
    "\N{U+0939}\N{U+093f}",
    "\N{U+092c}\N{U+0947}",
    "\N{U+091c}\N{U+093e}",
    "\N{U+0906}",
    "\N{U+0938}\N{U+094d}\N{U+0930}\N{U+093e}",
    "\N{U+092c}\N{U+093e}\N{U+0945}",
    "\N{U+0926}\N{U+093e}",
    "\N{U+0926}\N{U+093f}",
    "\N{U+092a}\N{U+093e}",
  ],
  month_stand_alone_wide => [
    "\N{U+092a}\N{U+0941}\N{U+0938}\N{U+0941} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
    "\N{U+092e}\N{U+093e}\N{U+0939}\N{U+093e}\N{U+0915}\N{U+093e} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
    "\N{U+092a}\N{U+093e}\N{U+0917}\N{U+0941}\N{U+0923}\N{U+0940} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
    "\N{U+0939}\N{U+093f}\N{U+0930}\N{U+0947} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
    "\N{U+092c}\N{U+0947}\N{U+0938}\N{U+0947} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
    "\N{U+091c}\N{U+093e}\N{U+091f}\N{U+093e} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
    "\N{U+0906}\N{U+0938}\N{U+093e}\N{U+0921}\N{U+093c}\N{U+0940} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
    "\N{U+0938}\N{U+094d}\N{U+0930}\N{U+093e}\N{U+092c}\N{U+093e}\N{U+0901} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
    "\N{U+092c}\N{U+094b}\N{U+0926}\N{U+094b} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
    "\N{U+0926}\N{U+0938}\N{U+093e}\N{U+0930}\N{U+093e} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
    "\N{U+0926}\N{U+093f}\N{U+0935}\N{U+0940} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
    "\N{U+092a}\N{U+093e}\N{U+0928}\N{U+094d}\N{U+0921}\N{U+0947} \N{U+0932}\N{U+0947}\N{U+091e}\N{U+094d}\N{U+091c}\N{U+0941}",
  ],
  name => "Kuvi Devanagari",
  native_language => "\N{U+0915}\N{U+0941}\N{U+0935}\N{U+093f}",
  native_name => "\N{U+0915}\N{U+0941}\N{U+0935}\N{U+093f} \N{U+0926}\N{U+0947}\N{U+0935}\N{U+0928}\N{U+093e}\N{U+0917}\N{U+0930}\N{U+0940}",
  native_script => "\N{U+0926}\N{U+0947}\N{U+0935}\N{U+0928}\N{U+093e}\N{U+0917}\N{U+0930}\N{U+0940}",
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+0915} \N{U+0967}",
    "\N{U+0915} \N{U+0968}",
    "\N{U+0915} \N{U+0969}",
    "\N{U+0915} \N{U+096a}",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+0967}\N{U+0938}\N{U+094d}\N{U+091f} \N{U+0915}\N{U+094d}\N{U+0935}\N{U+093e}\N{U+091f}\N{U+0930}",
    "\N{U+0968} \N{U+0915}\N{U+094d}\N{U+0935}\N{U+093e}\N{U+091f}\N{U+0930}",
    "\N{U+0969}\N{U+0930}\N{U+094d}\N{U+0921} \N{U+0915}\N{U+094d}\N{U+0935}\N{U+093e}\N{U+091f}\N{U+0930}",
    "\N{U+096a}\N{U+0925} \N{U+0915}\N{U+094d}\N{U+0935}\N{U+093e}\N{U+091f}\N{U+0930}",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+0915} \N{U+0967}",
    "\N{U+0915} \N{U+0968}",
    "\N{U+0915} \N{U+0969}",
    "\N{U+0915} \N{U+096a}",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+0967}\N{U+0938}\N{U+094d}\N{U+091f} \N{U+0915}\N{U+094d}\N{U+0935}\N{U+093e}\N{U+091f}\N{U+0930}",
    "\N{U+0968} \N{U+0915}\N{U+094d}\N{U+0935}\N{U+093e}\N{U+091f}\N{U+0930}",
    "\N{U+0969}\N{U+0930}\N{U+094d}\N{U+0921} \N{U+0915}\N{U+094d}\N{U+0935}\N{U+093e}\N{U+091f}\N{U+0930}",
    "\N{U+096a}\N{U+0925} \N{U+0915}\N{U+094d}\N{U+0935}\N{U+093e}\N{U+091f}\N{U+0930}",
  ],
  script => "Devanagari",
  territory => undef,
  time_format_full => "h:mm:ss\N{U+202f}a zzzz",
  time_format_long => "h:mm:ss\N{U+202f}a z",
  time_format_medium => "h:mm:ss\N{U+202f}a",
  time_format_short => "h:mm\N{U+202f}a",
  variant => undef,
  version => 46,
}
